@@ -1,6 +1,7 @@
 import warnings
 import traceback
 import textwrap
+import os
 
 _JUPYTER = 0
 _GUI = 0
@@ -15,6 +16,9 @@ try:
 except Exception:
     pass
 
+# To enable colors in cmd...
+os.system('')
+
 
 def user_warning(message):
     warnings.warn(f"\033[93m \n\n\t{message}\n\n \033[0m", stacklevel=2)
@@ -23,7 +27,7 @@ def user_warning(message):
 def traceback_warning(message=''):
     import pygments
 
-    separated_traceback = pygments.highlight(traceback.format_exc(), pygments.lexers.PythonTracebackLexer(), pygments.formatters.TerminalFormatter())
+    separated_traceback = pygments.highlight(traceback.format_exc(), pygments.lexers.PythonTracebackLexer(), pygments.formatters.Terminal256Formatter())
     separated_traceback = textwrap.indent(text=f"\n\n{message}\n====================\n\n{separated_traceback}\n====================\n", prefix='    ')
 
     warnings.warn(f"\n\n\n{separated_traceback}\n\n")
